==> Juice-0.0.0.tar.gz: Juice-0.0.0/setup.py <==
"""
Toucan

Toucan is a Flask based framework to help quickly develop web applications, by
adding structure to your views and templates.

Philosophy:

To create a framework that runs everywhere, regardless of the platform, by
providing cloud balh...

It made the following decisions for you: (of course you can change them)


It comes with pre-built components:


And it is still Flask.

http://pylot.io/
https://github.com/mardix/Toucan

"""

import os
from setuptools import setup, find_packages

base_dir = os.path.dirname(__file__)

__about__ = {}
with open(os.path.join(base_dir, "toucan", "__about__.py")) as f:
    exec(f.read(), __about__)

setup(
    name=__about__["name"],
    version=__about__["version"],
    license=__about__["license"],
    author=__about__["author"],
    author_email=__about__["email"],
    description=__about__["description"],
    url=__about__["uri"],
    long_description=__doc__,
    py_modules=['toucan'],
    entry_points=dict(console_scripts=[
        'toucan=toucan.cli:cli'
    ]),
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'Flask==0.10.1',
        'Flask-Assets==0.10',
        'flask-recaptcha==0.4.1',
        'flask-login==0.3.2',
        'flask-kvsession==0.6.1',
        'flask-s3==0.2.5',
        'flask-mail==0.9.0',
        'flask-cache==0.13.1',
        'flask-cloudy==0.13.1',
        'flask-seasurf==0.2.0',
        #'flask-babel==0.9',
        'Active-Alchemy==0.4.4',
        'Paginator==0.3.5',
        #'authomatic==0.1.0.post1',
        'six==1.9.0',
        'passlib==1.6.2',
        'bcrypt==1.1.1',
        'python-slugify==0.1.0',
        'humanize==0.5.1',
        'redis==2.9.1',
        'ses-mailer==0.13.0',
        'markdown==2.6.2',
        'inflection==0.3.1',
        'pyyaml==3.11',
        'click==5.1',
        'dicttoxml==1.6.6'
    ],
    keywords=['flask',
              'toucan',
              'templates',
              'views',
              'classy',
              'framework',
              "mvc",
              "blueprint",
              "toucan"],
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    zip_safe=False
)

==> Juice-0.0.1.tar.gz: Juice-0.0.1/setup.py <==
"""
Juice

Juice is a Flask based framework to help quickly develop web applications, by
adding structure to your views and templates.

Philosophy:

To create a framework that runs everywhere, regardless of the platform, by
providing cloud balh...

It made the following decisions for you: (of course you can change them)


It comes with pre-built components:


And it is still Flask.

http://pylot.io/
https://github.com/mardix/Juice

"""

import os
from setuptools import setup, find_packages

base_dir = os.path.dirname(__file__)

__about__ = {}
with open(os.path.join(base_dir, "juice", "__about__.py")) as f:
    exec(f.read(), __about__)

with open('requirements.txt') as f:
    install_requires = f.read().splitlines()

setup(
    name=__about__["__title__"],
    version=__about__["__version__"],
    license=__about__["__license__"],
    author=__about__["__author__"],
    author_email=__about__["__email__"],
    description=__about__["__summary__"],
    url=__about__["__uri__"],
    long_description=__doc__,
    py_modules=['juice'],
    entry_points=dict(console_scripts=[
        'juice=juice.cli:cli',
        'juice:cli=juice.cli:app_cli',
        'juice:serve=juice.cli:app_serve',
    ]),
    include_package_data=True,
    packages=find_packages(),
    install_requires=install_requires,
    keywords=['flask',
              'juice',
              'templates',
              'views',
              'classy',
              'framework',
              "mvc",
              "blueprint",
              "juice"],
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    zip_safe=False
)
